@@ -417,14 +417,9 @@ QThemeIconInfo XdgIconLoader::findIconHelper(const QString &themeName,
             // Try to reduce the amount of subDirs by looking in the GTK+ cache in order to save
             // a massive amount of file stat (especially if the icon is not there)
             auto cache = theme.m_gtkCaches.at(i);
-            bool isFindInCache = false; // 是否从缓存中查找图标
             if (cache->isValid() || cache->reValid(true)) {
                 const auto result = cache->lookup(iconNameFallback);
-                // 如果再次确认缓存可用
-                if (cache->isValid() &&
-                    // 如果图标对应的缓存子目录列表不为空
-                    !result.isEmpty()) {
-                    isFindInCache = true;
+                if (cache->isValid()) {
                     const QVector<QIconDirInfo> subDirsCopy = subDirs;
                     subDirs.clear();
                     subDirs.reserve(result.count());
@@ -440,47 +435,36 @@ QThemeIconInfo XdgIconLoader::findIconHelper(const QString &themeName,
                 }
             }
 
-            // 从子目录中获取图标
-            auto getEntriesFromSubDirs = [=](QThemeIconEntries &entries, const QString &contentDir
-                    , const QVector<QIconDirInfo> &subDirs) {
-                for (int j = 0; j < subDirs.size(); ++j) {
-                    const QIconDirInfo &dirInfo = subDirs.at(j);
-                    const QString subDir = contentDir + dirInfo.path + QLatin1Char('/');
-                    const QString pngPath = subDir + pngIconName;
-                    if (QFile::exists(pngPath)) {
-                        PixmapEntry *iconEntry = new PixmapEntry;
+            QString contentDir = contentDirs.at(i) + QLatin1Char('/');
+            for (int j = 0; j < subDirs.size() ; ++j) {
+                const QIconDirInfo &dirInfo = subDirs.at(j);
+                const QString subDir = contentDir + dirInfo.path + QLatin1Char('/');
+                const QString pngPath = subDir + pngIconName;
+                if (QFile::exists(pngPath)) {
+                    PixmapEntry *iconEntry = new PixmapEntry;
+                    iconEntry->dir = dirInfo;
+                    iconEntry->filename = pngPath;
+                    // Notice we ensure that pixmap entries always come before
+                    // scalable to preserve search order afterwards
+                    info.entries.prepend(iconEntry);
+                } else {
+                    const QString svgPath = subDir + svgIconName;
+                    if (gSupportsSvg && QFile::exists(svgPath)) {
+                        ScalableEntry *iconEntry = (followColorScheme() && theme.followsColorScheme()) ? new ScalableFollowsColorEntry : new ScalableEntry;
                         iconEntry->dir = dirInfo;
-                        iconEntry->filename = pngPath;
-                        // Notice we ensure that pixmap entries always come before
-                        // scalable to preserve search order afterwards
-                        entries.prepend(iconEntry);
-                    } else {
-                        const QString svgPath = subDir + svgIconName;
-                        if (gSupportsSvg && QFile::exists(svgPath)) {
-                            ScalableEntry *iconEntry = (followColorScheme() && theme.followsColorScheme()) ? new ScalableFollowsColorEntry : new ScalableEntry;
-                            iconEntry->dir = dirInfo;
-                            iconEntry->filename = svgPath;
-                            entries.append(iconEntry);
-                        }
-                    }
-                    const QString xpmPath = subDir + xpmIconName;
-                    if (QFile::exists(xpmPath)) {
-                        PixmapEntry *iconEntry = new PixmapEntry;
-                        iconEntry->dir = dirInfo;
-                        iconEntry->filename = xpmPath;
-                        // Notice we ensure that pixmap entries always come before
-                        // scalable to preserve search order afterwards
-                        entries.append(iconEntry);
+                        iconEntry->filename = svgPath;
+                        info.entries.append(iconEntry);
                     }
                 }
-            };
-
-            QString contentDir = contentDirs.at(i) + QLatin1Char('/');
-            getEntriesFromSubDirs(info.entries, contentDir, subDirs);
-            // 如果从缓存中没有找到图标，则在主题全目录进行查找
-            if (info.entries.isEmpty() && isFindInCache) {
-                subDirs = theme.keyList();
-                getEntriesFromSubDirs(info.entries, contentDir, subDirs);
+                const QString xpmPath = subDir + xpmIconName;
+                if (QFile::exists(xpmPath)) {
+                    PixmapEntry *iconEntry = new PixmapEntry;
+                    iconEntry->dir = dirInfo;
+                    iconEntry->filename = xpmPath;
+                    // Notice we ensure that pixmap entries always come before
+                    // scalable to preserve search order afterwards
+                    info.entries.append(iconEntry);
+                }
             }
         }
 
@@ -745,7 +729,7 @@ QIconLoaderEngineEntry *XdgIconLoaderEngine::entryForSize(const QSize &size, int
 
     // Find the minimum distance icon
     int minimalSize = INT_MAX;
-    QIconLoaderEngineEntry *closestMatch = 0;
+    QIconLoaderEngineEntry *closestMatch = nullptr;
     for (int i = 0; i < numEntries; ++i) {
         QIconLoaderEngineEntry *entry = m_info.entries.at(i);
         int distance = directorySizeDistance(entry->dir, iconsize, scale);
@@ -787,7 +771,7 @@ QSize XdgIconLoaderEngine::actualSize(const QSize &size, QIcon::Mode mode,
                 dir_size = qMin(pix_size.width(), pix_size.height());
             }
             int result = qMin(dir_size, qMin(size.width(), size.height()));
-            return QSize(result, result);
+            return {result, result};
         }
     }
     return {0, 0};
@@ -864,8 +848,8 @@ QPixmap ScalableFollowsColorEntry::pixmap(const QSize &size, QIcon::Mode mode, Q
             const QPalette pal = qApp->palette();
             // Note: indexes are assembled as in qtsvg (QSvgIconEnginePrivate::hashKey())
             QMap<int, QString> style_sheets;
-            style_sheets[(QIcon::Normal<<4)|QIcon::Off] = STYLE.arg(pal.windowText().color().name()).arg(pal.window().color().name()).arg(pal.highlight().color().name());
-            style_sheets[(QIcon::Selected<<4)|QIcon::Off] = STYLE.arg(pal.highlightedText().color().name()).arg(pal.highlight().color().name()).arg(pal.highlightedText().color().name());
+            style_sheets[(QIcon::Normal<<4)|QIcon::Off] = STYLE.arg(pal.windowText().color().name(), pal.window().color().name(), pal.highlight().color().name());
+            style_sheets[(QIcon::Selected<<4)|QIcon::Off] = STYLE.arg(pal.highlightedText().color().name(), pal.highlight().color().name(), pal.highlightedText().color().name());
             QMap<int, QSharedPointer<QXmlStreamWriter> > writers;
             for (auto i = style_sheets.cbegin(); i != style_sheets.cend(); ++i)
             {
